==> google-cloud-functions-0.4.0.tar.gz: google-cloud-functions-0.4.0/google/cloud/functions_v1/__init__.py <==
# -*- coding: utf-8 -*-

# Copyright 2020 Google LLC
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#

from .services.cloud_functions_service import CloudFunctionsServiceClient
from .types.functions import CallFunctionRequest
from .types.functions import CallFunctionResponse
from .types.functions import CloudFunction
from .types.functions import CloudFunctionStatus
from .types.functions import CreateFunctionRequest
from .types.functions import DeleteFunctionRequest
from .types.functions import EventTrigger
from .types.functions import FailurePolicy
from .types.functions import GenerateDownloadUrlRequest
from .types.functions import GenerateDownloadUrlResponse
from .types.functions import GenerateUploadUrlRequest
from .types.functions import GenerateUploadUrlResponse
from .types.functions import GetFunctionRequest
from .types.functions import HttpsTrigger
from .types.functions import ListFunctionsRequest
from .types.functions import ListFunctionsResponse
from .types.functions import SourceRepository
from .types.functions import UpdateFunctionRequest
from .types.operations import OperationMetadataV1
from .types.operations import OperationType


__all__ = (
    "CallFunctionRequest",
    "CallFunctionResponse",
    "CloudFunction",
    "CloudFunctionStatus",
    "CreateFunctionRequest",
    "DeleteFunctionRequest",
    "EventTrigger",
    "FailurePolicy",
    "GenerateDownloadUrlRequest",
    "GenerateDownloadUrlResponse",
    "GenerateUploadUrlRequest",
    "GenerateUploadUrlResponse",
    "GetFunctionRequest",
    "HttpsTrigger",
    "ListFunctionsRequest",
    "ListFunctionsResponse",
    "OperationMetadataV1",
    "OperationType",
    "SourceRepository",
    "UpdateFunctionRequest",
    "CloudFunctionsServiceClient",
)

==> google-cloud-functions-1.0.0.tar.gz: google-cloud-functions-1.0.0/google/cloud/functions_v1/__init__.py <==
# -*- coding: utf-8 -*-
# Copyright 2020 Google LLC
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#

from .services.cloud_functions_service import CloudFunctionsServiceClient
from .services.cloud_functions_service import CloudFunctionsServiceAsyncClient

from .types.functions import CallFunctionRequest
from .types.functions import CallFunctionResponse
from .types.functions import CloudFunction
from .types.functions import CreateFunctionRequest
from .types.functions import DeleteFunctionRequest
from .types.functions import EventTrigger
from .types.functions import FailurePolicy
from .types.functions import GenerateDownloadUrlRequest
from .types.functions import GenerateDownloadUrlResponse
from .types.functions import GenerateUploadUrlRequest
from .types.functions import GenerateUploadUrlResponse
from .types.functions import GetFunctionRequest
from .types.functions import HttpsTrigger
from .types.functions import ListFunctionsRequest
from .types.functions import ListFunctionsResponse
from .types.functions import SourceRepository
from .types.functions import UpdateFunctionRequest
from .types.functions import CloudFunctionStatus
from .types.operations import OperationMetadataV1
from .types.operations import OperationType

__all__ = (
    "CloudFunctionsServiceAsyncClient",
    "CallFunctionRequest",
    "CallFunctionResponse",
    "CloudFunction",
    "CloudFunctionStatus",
    "CloudFunctionsServiceClient",
    "CreateFunctionRequest",
    "DeleteFunctionRequest",
    "EventTrigger",
    "FailurePolicy",
    "GenerateDownloadUrlRequest",
    "GenerateDownloadUrlResponse",
    "GenerateUploadUrlRequest",
    "GenerateUploadUrlResponse",
    "GetFunctionRequest",
    "HttpsTrigger",
    "ListFunctionsRequest",
    "ListFunctionsResponse",
    "OperationMetadataV1",
    "OperationType",
    "SourceRepository",
    "UpdateFunctionRequest",
)
